@@ -1,12 +1,22 @@
+import warnings
 import weakref
 
 import numpy
-from numpy.testing import assert_array_equal
 import pytest
+from numpy.testing import assert_array_equal
 from thinc.api import NumpyOps, get_current_ops
 
-from spacy.attrs import DEP, ENT_IOB, ENT_TYPE, HEAD, IS_ALPHA, MORPH, POS
-from spacy.attrs import SENT_START, TAG
+from spacy.attrs import (
+    DEP,
+    ENT_IOB,
+    ENT_TYPE,
+    HEAD,
+    IS_ALPHA,
+    MORPH,
+    POS,
+    SENT_START,
+    TAG,
+)
 from spacy.lang.en import English
 from spacy.lang.xx import MultiLanguage
 from spacy.language import Language
@@ -81,6 +91,21 @@ def test_issue2396(en_vocab):
     assert (span.get_lca_matrix() == matrix).all()
 
 
+@pytest.mark.issue(11499)
+def test_init_args_unmodified(en_vocab):
+    words = ["A", "sentence"]
+    ents = ["B-TYPE1", ""]
+    sent_starts = [True, False]
+    Doc(
+        vocab=en_vocab,
+        words=words,
+        ents=ents,
+        sent_starts=sent_starts,
+    )
+    assert ents == ["B-TYPE1", ""]
+    assert sent_starts == [True, False]
+
+
 @pytest.mark.parametrize("text", ["-0.23", "+123,456", "±1"])
 @pytest.mark.parametrize("lang_cls", [English, MultiLanguage])
 @pytest.mark.issue(2782)
@@ -116,7 +141,8 @@ def test_issue3869(sentence):
 @pytest.mark.issue(3962)
 def test_issue3962(en_vocab):
     """Ensure that as_doc does not result in out-of-bound access of tokens.
-    This is achieved by setting the head to itself if it would lie out of the span otherwise."""
+    This is achieved by setting the head to itself if it would lie out of the span otherwise.
+    """
     # fmt: off
     words = ["He", "jests", "at", "scars", ",", "that", "never", "felt", "a", "wound", "."]
     heads = [1, 7, 1, 2, 7, 7, 7, 7, 9, 7, 7]
@@ -155,7 +181,8 @@ def test_issue3962(en_vocab):
 @pytest.mark.issue(3962)
 def test_issue3962_long(en_vocab):
     """Ensure that as_doc does not result in out-of-bound access of tokens.
-    This is achieved by setting the head to itself if it would lie out of the span otherwise."""
+    This is achieved by setting the head to itself if it would lie out of the span otherwise.
+    """
     # fmt: off
     words = ["He", "jests", "at", "scars", ".", "They", "never", "felt", "a", "wound", "."]
     heads = [1, 1, 1, 2, 1, 7, 7, 7, 9, 7, 7]
@@ -529,9 +556,9 @@ def test_doc_from_array_sent_starts(en_vocab):
     # no warning using default attrs
     attrs = doc._get_array_attrs()
     arr = doc.to_array(attrs)
-    with pytest.warns(None) as record:
+    with warnings.catch_warnings():
+        warnings.simplefilter("error")
         new_doc.from_array(attrs, arr)
-        assert len(record) == 0
     # only SENT_START uses SENT_START
     attrs = [SENT_START]
     arr = doc.to_array(attrs)
